@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Log::Any '$log';
 
-our $VERSION = '0.17'; # VERSION
+our $VERSION = '0.18'; # VERSION
 
 require Exporter;
 our @ISA       = qw(Exporter);
@@ -18,12 +18,6 @@ our @EXPORT_OK = qw(
                        bash_complete_spec_arg
                );
 
-use Data::Sah::Util; # tmp, for _parse_schema
-
-sub _parse_schema {
-    Data::Sah::Util::_parse_schema(@_);
-}
-
 # borrowed from Getopt::Complete. current problems: 1) '$foo' disappears because
 # shell will substitute it. 2) can't parse if closing quotes have not been
 # supplied (e.g. spanel get-plan "BISNIS A<tab>). at least it works with
@@ -224,9 +218,10 @@ sub bash_complete_spec_arg {
         return complete_env($word);
     }
 
+    require Data::Sah;
     my $args_spec = $spec->{args};
     $args_spec    = {
-        map { $_ => _parse_schema($args_spec->{$_}) }
+        map { $_ => Data::Sah::normalize_schema($args_spec->{$_}) }
             keys %$args_spec };
     my $args;
 
@@ -400,7 +395,7 @@ Sub::Spec::BashComplete - Provide bash completion for Sub::Spec::CmdLine program
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 SYNOPSIS
 
